import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { CallControl, ActivityButton } from '@collab-ui/react';

function styleInject(css, ref) {
  if (ref === void 0) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') {
    return;
  }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".styles_controlContainer__1Qd-l {\n  display: flex;\n  width: 100%;\n  padding: 0 20px;\n  justify-content: space-between;\n  align-items: center;\n  flex-wrap: wrap;\n  box-sizing: border-box;\n}\n\n.styles_controlItem__1mm5Z {\n  padding: 0 0;\n  flex: 0 1 auto;\n}\n\n.styles_button__3Vugn {\n  width: 56px;\n  height: 56px;\n  font-size: 24px;\n  line-height: 0.5;\n  color: #fff;\n  border-radius: 50%;\n}\n";
var styles = { "controlContainer": "styles_controlContainer__1Qd-l", "controlItem": "styles_controlItem__1mm5Z", "button": "styles_button__3Vugn" };
styleInject(css);

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var propTypes = {
  buttons: PropTypes.arrayOf(PropTypes.shape({
    accessibilityLabel: PropTypes.string,
    label: PropTypes.string,
    buttonClassName: PropTypes.string,
    buttonType: PropTypes.oneOfType([PropTypes.oneOf(['chat', 'camera', 'meetings', 'whiteboard', 'files', 'share-screen', 'tasks', 'microphone-muted', 'camera-muted', 'cancel']), PropTypes.shape({
      color: PropTypes.string,
      icon: PropTypes.element.isRequired
    })]),
    callControl: PropTypes.bool,
    onClick: PropTypes.func
  })).isRequired,
  showLabels: PropTypes.bool

};

var defaultProps = {
  showLabels: false
};

function ButtonControls(props) {
  var buttons = props.buttons,
      showLabels = props.showLabels;


  var buttonsRendered = buttons.map(function (button) {
    var label = showLabels && button.label ? button.label : '';

    if (button.callControl) {
      return React.createElement(CallControl, _extends({}, button, {
        label: label,
        ariaLabel: button.accessibilityLabel || button.label,
        type: button.buttonType
      }));
    }

    return React.createElement(ActivityButton, _extends({}, button, {
      label: label,
      ariaLabel: button.accessibilityLabel || button.label,
      type: button.buttonType
    }));
  });

  return React.createElement(
    'div',
    { className: classNames('ciscospark-controls-container', styles.controlContainer) },
    buttonsRendered
  );
}

ButtonControls.propTypes = propTypes;
ButtonControls.defaultProps = defaultProps;

export default ButtonControls;
//# sourceMappingURL=index.js.map
